summaryrefslogtreecommitdiffstats
path: root/agent
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2021-10-31 00:13:21 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2021-10-31 00:14:22 +0900
commite8933e99b4600d91e9eab7d1ad3a2d35813028a9 (patch)
treeb2899fd1ef651a1bff56918ace94625a4bc14aa0 /agent
parente8494e60efeb94c67c813d1c1c038031915e8c17 (diff)
downloadpolkit-tqt-e8933e99b4600d91e9eab7d1ad3a2d35813028a9.tar.gz
polkit-tqt-e8933e99b4600d91e9eab7d1ad3a2d35813028a9.zip
More Qt->TQt conversion and some clean up.
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'agent')
-rw-r--r--agent/CMakeLists.txt24
-rw-r--r--agent/listeneradapter.cpp14
-rw-r--r--agent/listeneradapter_p.h12
-rw-r--r--agent/polkitqt1-agent-listener.cpp28
-rw-r--r--agent/polkitqt1-agent-listener.h16
-rw-r--r--agent/polkitqt1-agent-session.cpp16
-rw-r--r--agent/polkitqt1-agent-session.h16
-rw-r--r--agent/polkitqtlistener.cpp48
-rw-r--r--agent/polkitqtlistener_p.h26
9 files changed, 100 insertions, 100 deletions
diff --git a/agent/CMakeLists.txt b/agent/CMakeLists.txt
index 80d1bd3b2..d131071b1 100644
--- a/agent/CMakeLists.txt
+++ b/agent/CMakeLists.txt
@@ -3,23 +3,23 @@ include_directories(
${CMAKE_CURRENT_SOURCE_DIR}
)
-set(polkit_qt_agent_SRCS
- polkitqt1-agent-session.cpp
- polkitqt1-agent-listener.cpp
+set(polkit_tqt_agent_SRCS
+ polkittqt1-agent-session.cpp
+ polkittqt1-agent-listener.cpp
listeneradapter.cpp
- polkitqtlistener.cpp
+ polkittqtlistener.cpp
)
-automoc4_add_library(polkit-qt-agent-1 SHARED ${polkit_qt_agent_SRCS})
+automoc4_add_library(polkit-tqt-agent-1 SHARED ${polkit_tqt_agent_SRCS})
-target_link_libraries(polkit-qt-agent-1
+target_link_libraries(polkit-tqt-agent-1
${POLKIT_LIBRARIES}
- ${QT_QTCORE_LIBRARY}
+ ${TQT_TQTCORE_LIBRARY}
${POLKIT_AGENT_LIBRARY}
- polkit-qt-core-1
+ polkit-tqt-core-1
)
-set_target_properties(polkit-qt-agent-1 PROPERTIES VERSION ${POLKITQT-1_LIBRARY_VERSION}
- SOVERSION ${POLKITQT-1_ABI_VERSION}
- DEFINE_SYMBOL MAKE_POLKITQT1_LIB)
+set_target_properties(polkit-tqt-agent-1 PROPERTIES VERSION ${POLKITTQT-1_LIBRARY_VERSION}
+ SOVERSION ${POLKITTQT-1_ABI_VERSION}
+ DEFINE_SYMBOL MAKE_POLKITTQT1_LIB)
-install(TARGETS polkit-qt-agent-1 ${INSTALL_TARGETS_DEFAULT_ARGS})
+install(TARGETS polkit-tqt-agent-1 ${INSTALL_TARGETS_DEFAULT_ARGS})
diff --git a/agent/polkitqt1-agent-session.cpp b/agent/polkitqt1-agent-session.cpp
index add3d95b1..c39600ff2 100644
--- a/agent/polkitqt1-agent-session.cpp
+++ b/agent/polkitqt1-agent-session.cpp
@@ -1,5 +1,5 @@
/*
- * This file is part of the PolKit1-qt project
+ * This file is part of the PolKit1-tqt project
* Copyright (C) 2009 Radek Novacek <rnovacek@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,11 +18,11 @@
* Boston, MA 02110-1301, USA.
*/
-#include "polkitqt1-agent-session.h"
+#include "polkittqt1-agent-session.h"
#include <TQtCore/TQDebug>
-#include "polkitqt1-identity.h"
+#include "polkittqt1-identity.h"
#define POLKIT_AGENT_I_KNOW_API_IS_SUBJECT_TO_CHANGE 1
#include <polkitagent/polkitagent.h>
@@ -104,7 +104,7 @@ void Session::Private::completed(PolkitAgentSession *s, gboolean gained_authoriz
{
tqDebug() << "COMPLETED";
Session *session = (Session *)user_data;
- Q_EMIT(session)->completed(gained_authorization);
+ TQ_EMIT(session)->completed(gained_authorization);
//free session here as polkit documentation asks
g_object_unref(session->d->polkitAgentSession);
@@ -114,19 +114,19 @@ void Session::Private::completed(PolkitAgentSession *s, gboolean gained_authoriz
void Session::Private::request(PolkitAgentSession *s, gchar *request, gboolean echo_on, gpointer user_data)
{
tqDebug() << "REQUEST";
- Q_EMIT((Session *)user_data)->request(TQString::fromUtf8(request), echo_on);
+ TQ_EMIT((Session *)user_data)->request(TQString::fromUtf8(request), echo_on);
}
void Session::Private::showError(PolkitAgentSession *s, gchar *text, gpointer user_data)
{
tqDebug() << "showError";
- Q_EMIT((Session *)user_data)->showError(TQString::fromUtf8(text));
+ TQ_EMIT((Session *)user_data)->showError(TQString::fromUtf8(text));
}
void Session::Private::showInfo(PolkitAgentSession *s, gchar *text, gpointer user_data)
{
tqDebug() << "showInfo";
- Q_EMIT((Session *)user_data)->showInfo(TQString::fromUtf8(text));
+ TQ_EMIT((Session *)user_data)->showInfo(TQString::fromUtf8(text));
}
//
@@ -166,4 +166,4 @@ void AsyncResult::setError(const TQString &text)
g_simple_async_result_set_error(d->result, POLKIT_ERROR, POLKIT_ERROR_FAILED, "%s", text.toUtf8().data());
}
-#include "polkitqt1-agent-session.moc"
+#include "polkittqt1-agent-session.moc"
diff --git a/agent/polkitqtlistener.cpp b/agent/polkitqtlistener.cpp
index ea0ad2dbf..dc5beb052 100644
--- a/agent/polkitqtlistener.cpp
+++ b/agent/polkitqtlistener.cpp
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -17,11 +17,11 @@
* the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301, USA.
*
- * polkit-qt-listener based on code by David Zeuthen <davidz@redhat.com>
+ * polkit-tqt-listener based on code by David Zeuthen <davidz@redhat.com>
*/
-#include "polkitqtlistener_p.h"
+#include "polkittqtlistener_p.h"
#include <stdio.h>
#include <TQtCore/TQDebug>
@@ -44,7 +44,7 @@ struct _PolkitTQtListenerClass {
PolkitAgentListenerClass parent_class;
};
-static void polkit_qt_listener_initiate_authentication(PolkitAgentListener *listener,
+static void polkit_tqt_listener_initiate_authentication(PolkitAgentListener *listener,
const gchar *action_id,
const gchar *message,
const gchar *icon_name,
@@ -55,29 +55,29 @@ static void polkit_qt_listener_initiate_authentication(PolkitAgentListener *lis
GAsyncReadyCallback callback,
gpointer user_data);
-static gboolean polkit_qt_listener_initiate_authentication_finish(PolkitAgentListener *listener,
+static gboolean polkit_tqt_listener_initiate_authentication_finish(PolkitAgentListener *listener,
GAsyncResult *res,
GError **error);
-G_DEFINE_TYPE(PolkitTQtListener, polkit_qt_listener, POLKIT_AGENT_TYPE_LISTENER);
+G_DEFINE_TYPE(PolkitTQtListener, polkit_tqt_listener, POLKIT_AGENT_TYPE_LISTENER);
-static void polkit_qt_listener_init(PolkitTQtListener *listener)
+static void polkit_tqt_listener_init(PolkitTQtListener *listener)
{
g_type_init();
}
-static void polkit_qt_listener_finalize(GObject *object)
+static void polkit_tqt_listener_finalize(GObject *object)
{
PolkitTQtListener *listener;
- listener = POLKIT_QT_LISTENER(object);
+ listener = POLKIT_TQT_LISTENER(object);
- if (G_OBJECT_CLASS(polkit_qt_listener_parent_class)->finalize != NULL) {
- G_OBJECT_CLASS(polkit_qt_listener_parent_class)->finalize(object);
+ if (G_OBJECT_CLASS(polkit_tqt_listener_parent_class)->finalize != NULL) {
+ G_OBJECT_CLASS(polkit_tqt_listener_parent_class)->finalize(object);
}
}
-static void polkit_qt_listener_class_init(PolkitTQtListenerClass *klass)
+static void polkit_tqt_listener_class_init(PolkitTQtListenerClass *klass)
{
GObjectClass *gobject_class;
PolkitAgentListenerClass *listener_class;
@@ -85,15 +85,15 @@ static void polkit_qt_listener_class_init(PolkitTQtListenerClass *klass)
gobject_class = G_OBJECT_CLASS(klass);
listener_class = POLKIT_AGENT_LISTENER_CLASS(klass);
- gobject_class->finalize = polkit_qt_listener_finalize;
+ gobject_class->finalize = polkit_tqt_listener_finalize;
- listener_class->initiate_authentication = polkit_qt_listener_initiate_authentication;
- listener_class->initiate_authentication_finish = polkit_qt_listener_initiate_authentication_finish;
+ listener_class->initiate_authentication = polkit_tqt_listener_initiate_authentication;
+ listener_class->initiate_authentication_finish = polkit_tqt_listener_initiate_authentication_finish;
}
-PolkitAgentListener *polkit_qt_listener_new(void)
+PolkitAgentListener *polkit_tqt_listener_new(void)
{
- return POLKIT_AGENT_LISTENER(g_object_new(POLKIT_QT_TYPE_LISTENER, NULL));
+ return POLKIT_AGENT_LISTENER(g_object_new(POLKIT_TQT_TYPE_LISTENER, NULL));
}
static void cancelled_cb(GCancellable *cancellable, gpointer user_data)
@@ -101,7 +101,7 @@ static void cancelled_cb(GCancellable *cancellable, gpointer user_data)
ListenerAdapter::instance()->cancelled_cb((PolkitAgentListener *)user_data);
}
-static void polkit_qt_listener_initiate_authentication(PolkitAgentListener *agent_listener,
+static void polkit_tqt_listener_initiate_authentication(PolkitAgentListener *agent_listener,
const gchar *action_id,
const gchar *message,
const gchar *icon_name,
@@ -112,14 +112,14 @@ static void polkit_qt_listener_initiate_authentication(PolkitAgentListener *age
GAsyncReadyCallback callback,
gpointer user_data)
{
- tqDebug() << "Listener adapter polkit_qt_listener_initiate_authentication";
- PolkitTQtListener *listener = POLKIT_QT_LISTENER(agent_listener);
+ tqDebug() << "Listener adapter polkit_tqt_listener_initiate_authentication";
+ PolkitTQtListener *listener = POLKIT_TQT_LISTENER(agent_listener);
// The result of asynchronous method will be created here and it will be pushed to the listener.
GSimpleAsyncResult *result = g_simple_async_result_new((GObject *) listener, callback, user_data, agent_listener);
tqDebug() << "GSimpleAsyncResult:" << result;
- ListenerAdapter::instance()->polkit_qt_listener_initiate_authentication(agent_listener,
+ ListenerAdapter::instance()->polkit_tqt_listener_initiate_authentication(agent_listener,
action_id,
message,
icon_name,
@@ -138,12 +138,12 @@ static void polkit_qt_listener_initiate_authentication(PolkitAgentListener *age
}
-static gboolean polkit_qt_listener_initiate_authentication_finish(PolkitAgentListener *listener,
+static gboolean polkit_tqt_listener_initiate_authentication_finish(PolkitAgentListener *listener,
GAsyncResult *res,
GError **error)
{
- tqDebug() << "Listener adapter polkit_qt_listener_initiate_authentication_finish";
- return ListenerAdapter::instance()->polkit_qt_listener_initiate_authentication_finish(listener,
+ tqDebug() << "Listener adapter polkit_tqt_listener_initiate_authentication_finish";
+ return ListenerAdapter::instance()->polkit_tqt_listener_initiate_authentication_finish(listener,
res,
error);
}
diff --git a/agent/listeneradapter.cpp b/agent/listeneradapter.cpp
index 231d7d752..7a531dfd5 100644
--- a/agent/listeneradapter.cpp
+++ b/agent/listeneradapter.cpp
@@ -1,5 +1,5 @@
/*
* This file is part of the Polkit-qt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -39,7 +39,7 @@ public:
ListenerAdapter *q;
};
-Q_GLOBAL_STATIC(ListenerAdapterHelper, s_globalListenerAdapter)
+TQ_GLOBAL_STATIC(ListenerAdapterHelper, s_globalListenerAdapter)
ListenerAdapter *ListenerAdapter::instance()
{
@@ -61,7 +61,7 @@ Listener* ListenerAdapter::findListener(PolkitAgentListener *listener)
{
Listener *listItem;
- Q_FOREACH(listItem, m_listeners) {
+ TQ_FOREACH(listItem, m_listeners) {
Q_ASSERT(listItem);
if (listItem->listener() == listener) {
@@ -72,7 +72,7 @@ Listener* ListenerAdapter::findListener(PolkitAgentListener *listener)
return NULL;
}
-void ListenerAdapter::polkit_qt_listener_initiate_authentication(PolkitAgentListener *listener,
+void ListenerAdapter::polkit_tqt_listener_initiate_authentication(PolkitAgentListener *listener,
const gchar *action_id,
const gchar *message,
const gchar *icon_name,
@@ -82,7 +82,7 @@ void ListenerAdapter::polkit_qt_listener_initiate_authentication(PolkitAgentList
GCancellable *cancellable,
GSimpleAsyncResult *result)
{
- tqDebug() << "polkit_qt_listener_initiate_authentication callback for " << listener;
+ tqDebug() << "polkit_tqt_listener_initiate_authentication callback for " << listener;
PolkitTQt1::Identity::List idents;
PolkitTQt1::Details dets(details);
@@ -102,11 +102,11 @@ void ListenerAdapter::polkit_qt_listener_initiate_authentication(PolkitAgentList
new AsyncResult(result));
}
-gboolean ListenerAdapter::polkit_qt_listener_initiate_authentication_finish(PolkitAgentListener *listener,
+gboolean ListenerAdapter::polkit_tqt_listener_initiate_authentication_finish(PolkitAgentListener *listener,
GAsyncResult *res,
GError **error)
{
- tqDebug() << "polkit_qt_listener_initiate_authentication_finish callback for " << listener;
+ tqDebug() << "polkit_tqt_listener_initiate_authentication_finish callback for " << listener;
GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT(res);
if (g_simple_async_result_propagate_error(simple, error)) {
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
diff --git a/agent/listeneradapter_p.h b/agent/listeneradapter_p.h
index 4bf754694..ed85f0470 100644
--- a/agent/listeneradapter_p.h
+++ b/agent/listeneradapter_p.h
@@ -1,5 +1,5 @@
/*
* This file is part of the Polkit-qt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -23,9 +23,9 @@
#include <TQtCore/TQObject>
-#include "polkitqt1-agent-listener.h"
-#include "polkitqt1-identity.h"
-#include "polkitqt1-details.h"
+#include "polkittqt1-agent-listener.h"
+#include "polkittqt1-identity.h"
+#include "polkittqt1-details.h"
typedef struct _GList GList;
typedef struct _GCancellable GCancellable;
@@ -51,7 +51,7 @@ public:
static ListenerAdapter* instance();
~ListenerAdapter() {}
- void polkit_qt_listener_initiate_authentication(PolkitAgentListener *listener,
+ void polkit_tqt_listener_initiate_authentication(PolkitAgentListener *listener,
const gchar *action_id,
const gchar *message,
const gchar *icon_name,
@@ -61,7 +61,7 @@ public:
GCancellable *cancellable,
GSimpleAsyncResult *result);
- gboolean polkit_qt_listener_initiate_authentication_finish(PolkitAgentListener *listener,
+ gboolean polkit_tqt_listener_initiate_authentication_finish(PolkitAgentListener *listener,
GAsyncResult *res,
GError **error);
void cancelled_cb(PolkitAgentListener *listener);
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
diff --git a/agent/polkitqt1-agent-listener.cpp b/agent/polkitqt1-agent-listener.cpp
index c6bf63cba..e6e3a9b00 100644
--- a/agent/polkitqt1-agent-listener.cpp
+++ b/agent/polkitqt1-agent-listener.cpp
@@ -1,5 +1,5 @@
/*
* This file is part of the Polkit-qt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,16 +18,16 @@
* Boston, MA 02110-1301, USA.
*/
-#include "polkitqt1-agent-listener.h"
+#include "polkittqt1-agent-listener.h"
#include <TQtCore/TQDebug>
-#include "polkitqtlistener_p.h"
+#include "polkittqtlistener_p.h"
-#include "polkitqt1-authority.h"
-#include "polkitqt1-subject.h"
-#include "polkitqt1-identity.h"
-#include "polkitqt1-details.h"
+#include "polkittqt1-authority.h"
+#include "polkittqt1-subject.h"
+#include "polkittqt1-identity.h"
+#include "polkittqt1-details.h"
namespace PolkitTQt1
{
@@ -39,7 +39,7 @@ class ListenerPrivate
{
public:
PolkitAgentListener *listener;
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
void *registeredHandle;
#endif
};
@@ -49,7 +49,7 @@ Listener::Listener(TQObject *parent)
{
g_type_init();
- d->listener = polkit_qt_listener_new();
+ d->listener = polkit_tqt_listener_new();
tqDebug() << "New PolkitAgentListener " << d->listener;
@@ -69,7 +69,7 @@ Listener::~Listener()
tqDebug("Destroying listener");
ListenerAdapter::instance()->removeListener(this);
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
if (d->registeredHandle) {
polkit_agent_listener_unregister(d->registeredHandle);
}
@@ -83,7 +83,7 @@ bool Listener::registerListener(const PolkitTQt1::Subject &subject, const TQStri
{
GError *error = NULL;
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
d->registeredHandle = polkit_agent_listener_register(d->listener,
POLKIT_AGENT_REGISTER_FLAGS_NONE,
#else
@@ -91,7 +91,7 @@ bool Listener::registerListener(const PolkitTQt1::Subject &subject, const TQStri
#endif
subject.subject(),
objectPath.toAscii().data(),
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
NULL,
#endif
&error);
@@ -101,7 +101,7 @@ bool Listener::registerListener(const PolkitTQt1::Subject &subject, const TQStri
g_error_free(error);
return false;
}
-#ifndef POLKIT_QT_1_COMPATIBILITY_MODE
+#ifndef POLKIT_TQT_1_COMPATIBILITY_MODE
if (d->registeredHandle == NULL) {
tqWarning() << TQString("Cannot register authentication agent!");
return false;
@@ -121,4 +121,4 @@ const PolkitAgentListener *Listener::listener()
}
-#include "polkitqt1-agent-listener.moc"
+#include "polkittqt1-agent-listener.moc"
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
diff --git a/agent/polkitqt1-agent-listener.h b/agent/polkitqt1-agent-listener.h
index ed48509e1..a5f2a0d40 100644
--- a/agent/polkitqt1-agent-listener.h
+++ b/agent/polkitqt1-agent-listener.h
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,14 +18,14 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef POLKITQT1_AGENT_LISTENER_H
-#define POLKITQT1_AGENT_LISTENER_H
+#ifndef POLKITTQT1_AGENT_LISTENER_H
+#define POLKITTQT1_AGENT_LISTENER_H
-#include "polkitqt1-export.h"
+#include "polkittqt1-export.h"
#include <TQtCore/TQObject>
-#include "polkitqt1-agent-session.h"
+#include "polkittqt1-agent-session.h"
#define POLKIT_AGENT_I_KNOW_API_IS_SUBJECT_TO_CHANGE 1
@@ -46,7 +46,7 @@ namespace Agent
class ListenerPrivate;
/**
- * \class Listener polkitqt1-agent-listener.h Listener
+ * \class Listener polkittqt1-agent-listener.h Listener
* \author Jaroslav Reznik <jreznik@redhat.com>
*
* \brief Listener is abstract class used for implementing authentication agents.
@@ -58,7 +58,7 @@ class ListenerPrivate;
* You can also use Session class to authenticate users however it isn't required.
* \sa Session
*/
-class POLKITQT1_EXPORT Listener : public TQObject
+class POLKITTQT1_EXPORT Listener : public TQObject
{
Q_OBJECT
TQ_DISABLE_COPY(Listener)
@@ -91,7 +91,7 @@ public:
*
* \param subject Subject that listener will be registered for
* \param objectPath DBus object path
* \return \c True if the polkitqt1-agent-listener.has been registered, \c False otherwise
*/
bool registerListener(const PolkitTQt1::Subject &subject, const TQString &objectPath);
@@ -91,7 +91,7 @@ public:
* \param subject Subject that listener will be registered for
* \param objectPath DBus object path
- * \return \c True if the polkitqt1-agent-listener.has been registered, \c False otherwise
+ * \return \c True if the polkittqt1-agent-listener.has been registered, \c False otherwise
*/
bool registerListener(const PolkitTQt1::Subject &subject, const TQString &objectPath);
diff --git a/agent/polkitqt1-agent-session.h b/agent/polkitqt1-agent-session.h
index f4f4ff49c..a40b5b867 100644
--- a/agent/polkitqt1-agent-session.h
+++ b/agent/polkitqt1-agent-session.h
@@ -1,5 +1,5 @@
/*
- * This file is part of the PolKit1-qt project
+ * This file is part of the PolKit1-tqt project
* Copyright (C) 2009 Radek Novacek <rnovacek@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -18,11 +18,11 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef POLKITQT1_AGENT_SESSION_H
-#define POLKITQT1_AGENT_SESSION_H
+#ifndef POLKITTQT1_AGENT_SESSION_H
+#define POLKITTQT1_AGENT_SESSION_H
#include <TQtCore/TQObject>
-#include "polkitqt1-identity.h"
+#include "polkittqt1-identity.h"
typedef struct _GSimpleAsyncResult GSimpleAsyncResult;
typedef struct _PolkitAgentSession PolkitAgentSession;
@@ -45,7 +45,7 @@ namespace Agent
* \internal
* \brief Encapsulation of GSimpleAsyncResult to TQObject class
*/
-class POLKITQT1_EXPORT AsyncResult
+class POLKITTQT1_EXPORT AsyncResult
{
public:
explicit AsyncResult(GSimpleAsyncResult *result);
@@ -70,14 +70,14 @@ private:
};
/**
- * \class Session polkitqt1-agent-session.h Session
+ * \class Session polkittqt1-agent-session.h Session
* \author Radek Novacek <rnovacek@redhat.com>
*
* This class is interface for interacting with native
* authentication system for obtaining authorizations.
*
*/
-class POLKITQT1_EXPORT Session : public TQObject
+class POLKITTQT1_EXPORT Session : public TQObject
{
Q_OBJECT
TQ_DISABLE_COPY(Session)
@@ -137,7 +137,7 @@ public:
Q_SIGNALS:
/**
* This signal will be emitted when the authentication
* polkitqt1-agent-session.has been completed or cancelled.
*
* \param gainedAuthorization \c True if authorization was successfully obtained.
*/
@@ -137,7 +137,7 @@ public:
/**
* This signal will be emitted when the authentication
- * polkitqt1-agent-session.has been completed or cancelled.
+ * polkittqt1-agent-session.has been completed or cancelled.
*
* \param gainedAuthorization \c True if authorization was successfully obtained.
diff --git a/agent/polkitqtlistener_p.h b/agent/polkitqtlistener_p.h
index c289b3973..b9f7faace 100644
--- a/agent/polkitqtlistener_p.h
+++ b/agent/polkitqtlistener_p.h
@@ -1,5 +1,5 @@
/*
* This file is part of the Polkit-qt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
* This library is free software; you can redistribute it and/or
@@ -17,11 +17,11 @@
* the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
* Boston, MA 02110-1301, USA.
*
* polkit-qt-listener based on code by David Zeuthen <davidz@redhat.com>
*/
-#ifndef POLKIQT_LISTENER_P_H
-#define POLKIQT_LISTENER_P_H
+#ifndef POLKITTQT_LISTENER_P_H
+#define POLKITTQT_LISTENER_P_H
#define POLKIT_AGENT_I_KNOW_API_IS_SUBJECT_TO_CHANGE 1
@@ -31,19 +31,19 @@
G_BEGIN_DECLS
-#define POLKIT_QT_TYPE_LISTENER (polkit_qt_listener_get_type())
-#define POLKIT_QT_LISTENER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), POLKIT_QT_TYPE_LISTENER, PolkitTQtListener))
-#define POLKIT_QT_LISTENER_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), POLKIT_QT_TYPE_LISTENER, PolkitTQtListenerClass))
-#define POLKIT_QT_LISTENER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), POLKIT_QT_TYPE_LISTENER, PolkitTQtListenerClass))
-#define POLKIT_QT_IS_LISTENER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), POLKIT_QT_TYPE_LISTENER))
-#define POLKIT_QT_IS_LISTENER_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), POLKIT_QT_TYPE_LISTENER))
+#define POLKIT_TQT_TYPE_LISTENER (polkit_tqt_listener_get_type())
+#define POLKIT_TQT_LISTENER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), POLKIT_TQT_TYPE_LISTENER, PolkitTQtListener))
+#define POLKIT_TQT_LISTENER_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), POLKIT_TQT_TYPE_LISTENER, PolkitTQtListenerClass))
+#define POLKIT_TQT_LISTENER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), POLKIT_TQT_TYPE_LISTENER, PolkitTQtListenerClass))
+#define POLKIT_TQT_IS_LISTENER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), POLKIT_TQT_TYPE_LISTENER))
+#define POLKIT_TQT_IS_LISTENER_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), POLKIT_TQT_TYPE_LISTENER))
typedef struct _PolkitTQtListener PolkitTQtListener;
typedef struct _PolkitTQtListenerClass PolkitTQtListenerClass;
-GType polkit_qt_listener_get_type(void) G_GNUC_CONST;
-PolkitAgentListener *polkit_qt_listener_new(void);
+GType polkit_tqt_listener_get_type(void) G_GNUC_CONST;
+PolkitAgentListener *polkit_tqt_listener_new(void);
G_END_DECLS
-#endif /* POLKIT_QT_LISTENER_H */
+#endif /* POLKIT_TQT_LISTENER_H */
@@ -1,5 +1,5 @@
/*
- * This file is part of the Polkit-qt project
+ * This file is part of the Polkit-tqt project
* Copyright (C) 2009 Jaroslav Reznik <jreznik@redhat.com>
*
@@ -17,11 +17,11 @@
* Boston, MA 02110-1301, USA.
*
- * polkit-qt-listener based on code by David Zeuthen <davidz@redhat.com>
+ * polkit-tqt-listener based on code by David Zeuthen <davidz@redhat.com>
*/